@@ -168,7 +168,7 @@ class KafkaClient(object):
         self._consumer_config = kafka.KafkaConsumer.DEFAULT_CONFIG
         self._topic_name = None
 
-        self._enable_logging(kwargs.get('root_logging', False))
+        self._enable_logging(kwargs.get('root_logging', False), kwargs.get('log_level', 'INFO'))
         logging.getLogger('kafka').propagate = False
         self._log = logging.getLogger('kafka.conn')
 
@@ -242,7 +242,7 @@ class KafkaClient(object):
             self.connection_close()
 
     @staticmethod
-    def _enable_logging(root_logging=True):
+    def _enable_logging(root_logging, log_level):
 
         try:
             log_dir = BuiltIn().replace_variables('${OUTPUT_DIR}')
@@ -265,7 +265,7 @@ class KafkaClient(object):
             },
             'handlers': {
                 'kafka_file': {
-                    'level': 'DEBUG',
+                    'level': log_level.upper(),
                     'class': 'logging.FileHandler',
                     'mode': 'w',
                     'filename': logfile_name,
@@ -275,7 +275,7 @@ class KafkaClient(object):
             'loggers': {
                 'kafka': {
                     'handlers': ['kafka_file'],
-                    'level': 'DEBUG',
+                    'level': log_level.upper(),
                     'propagate': False
                 }
             }
